'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var get = _interopDefault(require('lodash.get'));

/**
 * Improvement on top of React.lazy() that allows lazy rendering of named imports
 * Usage:
 *
 *  -- alternative to import { primary } from './Button'
 *  const PrimaryButton = lazier(() => import('./Button'), 'primary');
 *
 *  -- get the default import
 *  lazier(() => import('./Button'), 'default');
 *
 *  -- or
 *  lazier(() => import('./Button'));
 *
 */
/**
 * @param {() => Promise<*>} thenable
 * @param {String} name
 */
var lazier = function (thenable, name) {
    if (name === void 0) { name = 'default'; }
    return React.lazy(function () { return thenable().then(function (mod) { return ({ default: get(mod, name) }); }); });
};

module.exports = lazier;
//# sourceMappingURL=react-lazy-named.js.map
