/**
 * Improvement on top of React.lazy() that allows lazy rendering of named imports
 * Usage:
 *
 *  -- alternative to import { primary } from './Button'
 *  const PrimaryButton = lazier(() => import('./Button'), 'primary');
 *
 *  -- get the default import
 *  lazier(() => import('./Button'), 'default');
 *
 *  -- or
 *  lazier(() => import('./Button'));
 *
 */
import * as React from 'react';
declare type LazyNamed = (thenable: () => Promise<{
    [name: string]: React.ComponentType<any>;
}>, name: string) => React.LazyExoticComponent<React.ComponentType<any>>;
/**
 * @param {() => Promise<*>} thenable
 * @param {String} name
 */
declare const lazier: LazyNamed;
export default lazier;
